"""
HTML report objects
"""


#[

from __future__ import annotations

import documark as _dm

#]


__all__ = (
    "Rephrase",
)


@_dm.reference(
    path=("visualization_reporting", "html_reports.md", ),
    categories={
        "constructor": "Creating new `Rephrase` objects",
        "property": None,
    }
)
class Rephrase:
    """
················································································

HTML reports
=============

HTML reports are implemented as `Rephrase` objects.

················································································
    """

    @_dm.reference(category="constructor", call_name="Rephrase", )
    def __init__(
        self,
        /,
    ) -> None:
        """
················································································

==Create a new `Rephrase` object==

················································································
        """
        pass


